<?php
	/*
		 _____  ____  _        ______
		|  __ \|  _ \| |      |  ____|
		| |  | | |_) | |      | |__ _ __ __ _ _ __   ___ ___
		| |  | |  _ <| |      |  __| '__/ _` | '_ \ / __/ _ \
		| |__| | |_) | |____  | |  | | | (_| | | | | (_|  __/
		|_____/|____/|______| |_|  |_|  \__,_|_| |_|\___\___|
     * Copyright
     * Classe pour les Modules & SDK FFVE Services
    */    

	class FFVE_API
	{
		private $login;
		private $password;
		private $server;
		public function __construct($server,$login, $password)
		{
			$this->server = $server;
			$this->login = $login;
			$this->password = $password;
		}
		private function make_request($endpoint, $requestData,$debug = false) {
			$apiUrl = 'https://' . $this->server . '/wp-json/dbl-ffve/v1/' . $endpoint;
			// Initialiser cURL
			$ch = curl_init($apiUrl);
			// Configurer les options de cURL
			curl_setopt($ch, CURLOPT_POST, 1);
			if (isset($requestData['products'])){
				curl_setopt($ch, CURLOPT_POSTFIELDS, $requestData);
				curl_setopt($ch, CURLOPT_HTTPHEADER, array('Content-Type: multipart/form-data'));
			}else{
			curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($requestData));
			curl_setopt($ch, CURLOPT_HTTPHEADER, array('Content-Type: application/x-www-form-urlencoded'));
			}
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
			// Exécuter la requête cURL
			$responseJSON = curl_exec($ch);
			// print $responseJSON;
			$response = json_decode($responseJSON, true);
			// Vérifier les erreurs
			if (curl_errno($ch)) {
				error_log('cURL error: ' . curl_error($ch));
				if ($debug){
					$message = $responseJSON;
				}else{
					$message = 'Erreur cURL';
				}
				return ['success'=>false,'message'=>  $message ];
			}
			if ($debug && !$response ){
						$message =  $responseJSON;
						return ['success'=>false,'message'=>  $message ];
			}
			// Fermer la session cURL
			curl_close($ch);
			return $response;
		}
		
		
		public function decodeToken($token)	{
			// Prepare the request data
			$requestData = array(
            'token' => $token,
            'login' => $this->login,
            'password' => $this->password,
			);
			$response = $this->make_request('decode-token', $requestData);
			return $response;
		}
			
		
		public function uploadProducts($file_path)	{
			if (!file_exists($file_path)){
					return ['success'=>false,'message'=>'Fichier export non généré'];
			}
			// Prepare the request data
			$requestData = array(
            'login' => $this->login,
            'password' => $this->password,
			 'products' => new CURLFile($file_path, 'text/csv', 'FFVE-SERVICES-Export.csv')
			);
			$response = $this->make_request('upload-products', $requestData);
			// Vérifier les erreurs
			if (@$response['success'] === true) {
				FFVE_TOOLS::addLog('Produits envoyés à FFVE Services', 1, '200');
				// Code incorrect
				return ['success' => true];
				} else {
				FFVE_TOOLS::addLog('Erreur produits non envoyés à FFVE Services', 3, '403');
				if (_FFVE_SERVICES_DEBUG_)
					error_log(print_r($response,true));
				
                return ['success' => false, 'message' => @$response['message'] ?? 'Code 408' ];
			}
		}
		
		
		// Function to check if a coupon code exists via the REST API
		public function checkCouponCodeExists($couponCode)	{
			// Prepare the request data
			$requestData = array(
            'coupon_code' => $couponCode,
            'login' => $this->login,
            'password' => $this->password,
			);
			if ( _FFVE_SERVICES_DEBUG_ ){error_log( "REQUEST API " . print_r($requestData,true));}
			$response = $this->make_request('coupon-existe', $requestData);
			if ( _FFVE_SERVICES_DEBUG_ ){error_log( "REPONSE API " . print_r($response,true));}
			// Vérifier les erreurs
			if (@$response['success'] === true) {
				FFVE_TOOLS::addLog('Code membre validé FFVE Services', 1, '200');
				// Code incorrect
				return true;
				} else {
				FFVE_TOOLS::addLog('Code membre inconnu FFVE Services', 3, '403');
				return false; // Le code de réduction existe
			}
		}
		public function checkConfig(){
			if (!$this->server || !$this->login || !$this->password ){
				return ['success'=>false,'message'=>'Merci de renseigner votre identifiant, mot de passe et le serveur API'];
			}
			// Prepare the request data
			$info_server = FFVE_TOOLS::moduleInfo();
			$requestData = array(
			'login' => $this->login,
			'password' => $this->password,
			'source' => $info_server,
			);
			$response = $this->make_request('check-config', $requestData,true);
			// Vérifier les erreurs
			if (@$response['config'] == "OK") {
				FFVE_TOOLS::addLog('Configuration validée FFVE Services', 1, '200');
				return ['success'=>true];
				} else {
				FFVE_TOOLS::addLog('Erreur configuration FFVE Services', 3, '403');
				$message = "<br>Serveur : " . $this->server . "<br>";
				$message .= "Identifiant : " . $this->login . "<br>";
				$message .= "Réponse du serveur API : " . @$response['message'] . "<br>";
				return ['success'=>false, 'message'=> $message ];
			}
		}
		public function setTransaction($reference, $payload){
			//
			
			$submittedCouponCode=@$payload['submittedCouponCode'];
			$totalOrderAmount=@$payload['totalOrderAmount']??0;
			$totalQuantity=@$payload['totalQuantity']??0;
			$totalHT=@$payload['totalHT']??0;
			$shippingAmount=@$payload['shippingAmount']??0;
			$orderStatus=@$payload['orderStatus']??0;
			
			
			if (!$submittedCouponCode){
				$submittedCouponCode = "Erreur/Inconnu";
			}
			// Prepare the request data
			$requestData = array(
            'coupon_code' => $submittedCouponCode,
            'login' => $this->login,
            'password' => $this->password,
            'action' => 'V',
            'total' => $totalOrderAmount,
            'totalHT' => $totalHT,
            'shippingAmount' => $shippingAmount,
            'orderStatus' => $orderStatus,
            'quantity' => $totalQuantity,
            'reference' => $reference,
			);
			$response = $this->make_request('transaction', $requestData);
			if (is_array($response) && $response['success'] === true) {
				FFVE_TOOLS::addLog('Export commande vers FFVE Services', 1, '200', 'Order', null);
				return $response;
				} else {
				if (!is_array($response)){
						$response_arr['message'] = $response;
						
				}else{
						$response_arr['message'] = $response['message'];
				}
				FFVE_TOOLS::addLog('Erreur export commande vers FFVE Services' .  $response_arr['message'], 3, '403', 'Order', null);
				return ['success' => false ];
			}
		}
		
		
		function afficherBandeau() {
			 ?>
    <script>
        document.addEventListener("DOMContentLoaded", function() {
            // Créer le bandeau
            var bandeau = document.createElement("div");
            bandeau.style.position = "fixed";
            bandeau.style.bottom = "0";
            bandeau.style.left = "0";
            bandeau.style.width = "100%";
            bandeau.style.backgroundColor = "rgba(255, 0, 0, 0.8)"; // Rouge avec transparence
            bandeau.style.color = "white";
            bandeau.style.textAlign = "center";
            bandeau.style.padding = "10px";
            bandeau.style.zIndex = "9999"; // Assurer que le bandeau est au-dessus de tout autre élément

            // Ajouter le texte au bandeau
            bandeau.innerText = "Bienvenue Membre de FFVE Services.";

            // Ajouter le bandeau au corps de la page
            document.body.appendChild(bandeau);
        });
    </script>
    <?php
}
	
		
	}			
